from setuptools import setup

setup(name='GussBinoDist',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['GussBinoDist'],
      auther='sana sabah',
      auther_email='sana_sabah@uoitc.edu.iq',
      zip_safe=False)
